@@ -5,7 +5,7 @@ sub __isqrtrem__ {
     my ($x) = @_;
 
     Math::GMPz::Rmpz_sgn($x) < 0
-      and return (&Math::AnyNum::_nan(), &Math::AnyNum::_nan());
+      and return (_nan(), _nan());
 
     my $r = Math::GMPz::Rmpz_init();
     my $s = Math::GMPz::Rmpz_init();
