@@ -7,13 +7,8 @@ Class::Multimethods::multimethod __numify__ => qw(Math::MPFR) => sub {
     Math::MPFR::Rmpfr_get_d($_[0], $ROUND);
 };
 
-Class::Multimethods::multimethod __numify__ => qw(Math::GMPq) => sub {
-    Math::GMPq::Rmpq_get_d($_[0]);
-};
-
-Class::Multimethods::multimethod __numify__ => qw(Math::GMPz) => sub {
-    Math::GMPz::Rmpz_get_d($_[0]);
-};
+Class::Multimethods::multimethod __numify__ => qw(Math::GMPq) => \&Math::GMPq::Rmpq_get_d;
+Class::Multimethods::multimethod __numify__ => qw(Math::GMPz) => \&Math::GMPz::Rmpz_get_d;
 
 Class::Multimethods::multimethod __numify__ => qw(Math::MPC) => sub {
     my ($x) = @_;
